Module blaxel.models.store_configuration_option
===============================================

Classes
-------

`StoreConfigurationOption(if_: blaxel.types.Unset | str = <blaxel.types.Unset object>, label: blaxel.types.Unset | str = <blaxel.types.Unset object>, value: blaxel.types.Unset | str = <blaxel.types.Unset object>)`
:   Store configuration options for a select type configuration
    
    Attributes:
        if_ (Union[Unset, str]): Conditional rendering for the configuration option, example: provider === 'openai'
        label (Union[Unset, str]): Store configuration option label
        value (Union[Unset, str]): Store configuration option value
    
    Method generated by attrs for class StoreConfigurationOption.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `if_: blaxel.types.Unset | str`
    :

    `label: blaxel.types.Unset | str`
    :

    `value: blaxel.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :